@@ -21,16 +21,16 @@ package MongoDB::Op::_Aggregate;
 # Encapsulate aggregate operation; return MongoDB::QueryResult
 
 use version;
-our $VERSION = 'v1.8.1';
+our $VERSION = 'v1.8.2';
 
 use Moo;
 
 use MongoDB::Op::_Command;
 use MongoDB::_Types qw(
     ArrayOfHashRef
+    Boolish
 );
 use Types::Standard qw(
-    Bool
     HashRef
     InstanceOf
 );
@@ -58,7 +58,7 @@ has options => (
 has has_out => (
     is       => 'ro',
     required => 1,
-    isa      => Bool,
+    isa      => Boolish,
 );
 
 with $_ for qw(
