@@ -25,7 +25,7 @@ use warnings;
 package MongoDB::_Link;
 
 use version;
-our $VERSION = 'v1.8.0';
+our $VERSION = 'v1.8.2';
 
 use Moo;
 use Errno qw[EINTR EPIPE];
@@ -36,12 +36,12 @@ use Time::HiRes qw/time/;
 use MongoDB::Error;
 use MongoDB::_Constants;
 use MongoDB::_Types qw(
+    Boolish
     HostAddress
     NonNegNum
     ServerDesc
 );
 use Types::Standard qw(
-    Bool
     HashRef
     Maybe
     Num
@@ -51,7 +51,7 @@ use Types::Standard qw(
 use namespace::clean;
 
 my $SOCKET_CLASS =
-  eval { require IO::Socket::IP; IO::Socket::IP->VERSION(0.25) }
+  eval { require IO::Socket::IP; IO::Socket::IP->VERSION(0.32) }
   ? 'IO::Socket::IP'
   : 'IO::Socket::INET';
 
@@ -75,7 +75,7 @@ has socket_timeout => (
 
 has with_ssl => (
     is => 'ro',
-    isa => Bool,
+    isa => Boolish,
 );
 
 has SSL_options => (
@@ -119,14 +119,14 @@ for my $f ( @is_master_fields ) {
 has does_write_commands => (
     is => 'rwp',
     init_arg => undef,
-    isa => Bool,
+    isa => Boolish,
 );
 
 # for caching wire version >= 5
 has supports_collation => (
     is => 'rwp',
     init_arg => undef,
-    isa => Bool,
+    isa => Boolish,
 );
 
 my @connection_state_fields = qw(
@@ -426,6 +426,7 @@ sub read {
         }
 
         if ( !defined $len ) {
+            next if length($msg) < 4;
             $len = unpack( P_INT32, $msg );
             MongoDB::ProtocolError->throw(
                 qq/Server reply of size $len exceeds maximum of / . $self->{max_message_size_bytes} )
