@@ -21,14 +21,14 @@ package MongoDB::_Types;
 # MongoDB type definitions
 
 use version;
-our $VERSION = 'v1.8.1';
+our $VERSION = 'v1.8.2';
 
 use Type::Library
   -base,
   -declare => qw(
   ArrayOfHashRef
   AuthMechanism
-  Booleanpm
+  Boolish
   BSONCodec
   ConnectType
   CursorType
@@ -90,7 +90,11 @@ declare ArrayOfHashRef, as ArrayRef [HashRef];
 enum AuthMechanism,
   [qw/NONE DEFAULT MONGODB-CR MONGODB-X509 GSSAPI PLAIN SCRAM-SHA-1/];
 
-class_type Booleanpm, { class => 'boolean' };
+# Types::Standard::Bool is overly restrictive, not allowing objects that
+# overload boolification, and Overload['bool'] doesn't detect objects that
+# overload via fallback, so we use this type for documentation purposes,
+# but allow any actual type.
+declare Boolish, as Any;
 
 duck_type BSONCodec, [ qw/encode_one decode_one/ ];
 
@@ -186,7 +190,7 @@ coerce ArrayOfHashRef, from HashRef, via { [$_] };
 coerce BSONCodec, from HashRef,
   via { require MongoDB::BSON; MongoDB::BSON->new($_) };
 
-coerce Booleanpm, from Any, via { boolean($_) };
+coerce Boolish, from Any, via { !!$_ };
 
 coerce DBRefColl, from MongoDBCollection, via { $_->name };
 
